#ifndef UTILS_H
#define UTILS_H

#include <QObject>
#include <QtDBus>
#include <QDebug>


class KeypadOnHelper : public QObject
{
    Q_OBJECT
public:
    explicit KeypadOnHelper(QObject *parent = 0);


private:
    QDBusMessage _unpauseKeys;
    QTimer *unpauseTimer;

signals:

private slots:
    void onLockChanged(QString msg);
    void unpauseKeys();

public slots:
    
};

#endif // UTILS_H
